# Project — System Evolution

> Auto-generated by Chronicle. Edit `summary:` fields to add context.

## Era: Genesis → v0.5.0 | 2026-03-28 – 2026-03-30

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

---

## Era: v0.5.0 → v0.5.1 | 2026-03-30 – 2026-03-30

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `pyproject.toml`
- `src/llm_router/profiles.py`
- `src/llm_router/router.py`
- `src/llm_router/types.py`

---

## Era: v0.5.1 → v0.5.2 | 2026-03-30 – 2026-03-30

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.playwright-mcp/page-2026-03-30T09-47-22-536Z.png`
- `CHANGELOG.md`
- `README.md`
- `docs/PROVIDERS.md`
- `pyproject.toml`

---

## Era: v0.5.2 → v1.1.0 | 2026-03-30 – 2026-04-01

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.DS_Store`
- `.claude/hooks/auto-route.py`
- `.github/workflows/benchmarks.yml`
- `.gitignore`
- `.playwright-mcp/page-2026-03-30T09-47-22-536Z.png`

---

## Era: v1.1.0 → v1.3.0 | 2026-04-01 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude/settings.json`
- `CHANGELOG.md`
- `Dockerfile`
- `README.md`

---

## Era: v1.3.0 → v1.3.1 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.github/workflows/publish.yml`
- `Dockerfile`
- `mcp-registry.json`
- `pyproject.toml`
- `src/llm_router/cli.py`

---

## Era: v1.3.1 → v1.3.2 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.github/workflows/publish.yml`
- `CLAUDE.md`
- `pyproject.toml`

---

## Era: v1.3.2 → v1.3.3 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `pyproject.toml`
- `smithery.yaml`
- `src/llm_router/cli.py`

---

## Era: v1.3.3 → v1.3.4 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `pyproject.toml`
- `src/llm_router/cli.py`

---

## Era: v1.3.4 → v1.3.5 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/classifier.py`
- `src/llm_router/cli.py`
- `src/llm_router/hooks/auto-route.py`

---

## Era: v1.3.5 → v1.3.6 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `demo/demo.tape`
- `docs/images/demo.gif`
- `pyproject.toml`

---

## Era: v1.3.6 → v1.3.7 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/router.py`

---

## Era: v1.3.7 → v1.3.8 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `demo/demo.tape`
- `docs/images/demo.gif`
- `pyproject.toml`
- `src/llm_router/cli.py`

---

## Era: v1.3.8 → v1.3.9 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `docs/images/demo.png`
- `pyproject.toml`

---

## Era: v1.3.9 → v1.4.0 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.github/workflows/ci.yml`
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/cli.py`
- `src/llm_router/install_hooks.py`

---

## Era: v1.4.0 → v1.4.1 | 2026-04-05 – 2026-04-05

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `Procfile`
- `pyproject.toml`
- `railway.toml`
- `smithery.yaml`

---

## Era: v1.4.1 → v1.4.2 | 2026-04-05 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `ROADMAP.md`
- `TODO.md`
- `docs/demo.cast`

---

## Era: v1.4.2 → v1.5.0 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `TODO.md`
- `pyproject.toml`
- `src/llm_router/cli.py`
- `src/llm_router/server.py`

---

## Era: v1.5.0 → v1.5.1 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/hooks/session-end.py`

---

## Era: v1.5.1 → v1.5.2 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/hooks/status-bar.py`

---

## Era: v1.5.2 → v1.6.0 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `pyproject.toml`
- `src/llm_router/cli.py`
- `src/llm_router/hooks/session-end.py`

---

## Era: v1.6.0 → v1.7.0 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `ROADMAP.md`
- `docs/plans/v2.0-ecosystem-integrations.md`
- `pyproject.toml`

---

## Era: v1.7.0 → v1.8.0 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/cli.py`
- `src/llm_router/hooks/session-end-clawcode.py`
- `src/llm_router/hooks/session-end.py`

---

## Era: v1.8.0 → v1.8.1 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/hooks/auto-route.py`

---

## Era: v1.8.1 → v1.8.2 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/cli.py`
- `src/llm_router/hooks/session-start.py`
- `uv.lock`

---

## Era: v1.8.2 → v1.8.3 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.github/workflows/publish.yml`
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/hooks/auto-route.py`
- `src/llm_router/install_hooks.py`

---

## Era: v1.8.3 → v1.8.4 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `CLAUDE.md`
- `README.md`
- `pyproject.toml`
- `src/llm_router/hooks/auto-route.py`

---

## Era: v1.8.4 → v1.8.5 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `pyproject.toml`

---

## Era: v1.8.5 → v1.9.0 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.playwright-mcp/console-2026-04-04T14-31-43-041Z.log`
- `.playwright-mcp/console-2026-04-04T15-38-48-026Z.log`
- `.playwright-mcp/console-2026-04-04T16-11-26-751Z.log`
- `.playwright-mcp/console-2026-04-04T16-11-54-015Z.log`
- `.playwright-mcp/page-2026-04-04T14-31-43-321Z.yml`

---

## Era: v1.9.0 → v1.9.1 | 2026-04-06 – 2026-04-06

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/tools/routing.py`

---

## Era: v1.9.1 → v1.9.2 | 2026-04-06 – 2026-04-07

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/config.py`

---

## Era: v1.9.2 → v1.9.3 | 2026-04-07 – 2026-04-07

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/config.py`

---

## Era: v1.9.3 → v1.9.4 | 2026-04-07 – 2026-04-07

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.github/workflows/ci.yml`
- `.github/workflows/publish.yml`
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/router.py`

---

## Era: v1.9.4 → v2.0.0 | 2026-04-07 – 2026-04-07

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `CHANGELOG.md`
- `README.md`
- `pyproject.toml`
- `src/llm_router/integrations/__init__.py`
- `src/llm_router/integrations/agno.py`

---

## Era: v2.0.0 → v2.0.2 | 2026-04-07 – 2026-04-07

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.DS_Store`
- `.github/workflows/ci.yml`
- `.github/workflows/publish.yml`
- `.gitignore`
- `CHANGELOG.md`

---

## Era: v2.0.2 → v2.0.1 | 2026-04-07 – 2026-04-07

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.DS_Store`
- `.claude-plugin/plugin.json`
- `.github/workflows/ci.yml`
- `.github/workflows/publish.yml`
- `.gitignore`

---

## Era: v2.0.1 → v2.1.0 | 2026-04-07 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.DS_Store`
- `.claude-plugin/plugin.json`
- `.github/workflows/ci.yml`
- `.github/workflows/publish.yml`
- `.gitignore`

---

## Era: v2.1.0 → v2.2.0 | 2026-04-08 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/plugin.json`
- `CHANGELOG.md`
- `README.md`
- `ROADMAP.md`
- `pyproject.toml`

---

## Era: v2.2.0 → v2.3.0 | 2026-04-08 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `src/llm_router/cli.py`
- `src/llm_router/hooks/auto-route.py`
- `src/llm_router/hooks/enforce-route.py`
- `src/llm_router/hooks/session-end.py`
- `src/llm_router/hooks/session-start.py`

---

## Era: v2.3.0 → v2.4.0 | 2026-04-08 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `src/llm_router/cli.py`
- `src/llm_router/hooks/auto-route.py`
- `src/llm_router/hooks/session-end.py`
- `src/llm_router/repo_config.py`
- `src/llm_router/router.py`

---

## Era: v2.4.0 → v2.5.0 | 2026-04-08 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/plugin.json`
- `CHANGELOG.md`
- `CLAUDE.md`
- `README.md`
- `pyproject.toml`

---

## Era: v2.5.0 → v2.6.0 | 2026-04-08 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/plugin.json`
- `CHANGELOG.md`
- `CLAUDE.md`
- `README.md`
- `pyproject.toml`

---

## Era: v2.6.0 → v3.0.0 | 2026-04-08 – 2026-04-08

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/plugin.json`
- `.llm-router.yml`
- `CHANGELOG.md`
- `pyproject.toml`
- `src/llm_router/cli.py`

---

## Era: v3.0.0 → v3.1.0 | 2026-04-08 – 2026-04-09

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `CHANGELOG.md`
- `CLAUDE.md`
- `README.md`

---

## Era: v3.1.0 → v3.2.0 | 2026-04-09 – 2026-04-09

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `CHANGELOG.md`
- `README.md`
- `ROADMAP.md`

---

## Era: v3.2.0 → v3.2.1 | 2026-04-09 – 2026-04-09

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `.github/workflows/hol-skill-validate.yml`
- `CHANGELOG.md`
- `ROADMAP.md`

---

## Era: v3.2.1 → v3.3.0 | 2026-04-09 – 2026-04-10

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `.codex-plugin/.mcp.json`
- `.codex-plugin/marketplace.json`
- `.codex-plugin/plugin.json`

---

## Era: v3.3.0 → v3.4.0 | 2026-04-10 – 2026-04-10

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `.codex-plugin/marketplace.json`
- `.codex-plugin/plugin.json`
- `CHANGELOG.md`

---

## Era: v3.4.0 → v3.5.0 | 2026-04-10 – 2026-04-10

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `.codex-plugin/marketplace.json`
- `.codex-plugin/plugin.json`
- `.factory-plugin/marketplace.json`

---

## Era: v3.5.0 → v3.6.0 | 2026-04-10 – 2026-04-10

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `.factory-plugin/marketplace.json`
- `.factory-plugin/plugin.json`
- `CHANGELOG.md`

---

## Era: v3.6.0 → v4.0.0 | 2026-04-10 – 2026-04-10

**Decisions (21):**
- Introduce Tool Slim Mode, Real-Time Session Spend ⚠ [ADR]
- Add VS Code and Cursor IDE install support ~ [ADR]
- Introduce multi-agent CLI compatibility and new pl ⚠ [ADR]
- Agent-context chain reordering for LLM selection ~ [ADR]
- Ensure JSONL savings are flushed before cumulative ~
- Introduce Codex CLI plugin support and marketplace ⚠ [ADR]
- Introduce Policy Engine, Savings Digest, and Commu ⚠ [ADR]
- Add multi-host adapter support for Codex CLI, Clau ~ [ADR]
- Introduce llm_auto tool for host-agnostic savings ~ [ADR]
- Block Glob/Read/Grep/LS for Q&A tasks in hard enfo ~
- Always inject Ollama models when configured ~
- Introduce Team Dashboard with Multi-Channel Push N ⚠ [ADR]
- Always inject Ollama into routing chain when confi ~
- Enhance savings projection accuracy and persistenc ~ [ADR]
- Introduce Latency-Aware and Personalized Routing w ⚠ [ADR]
- Context-aware routing for short continuation promp ~
- Introduce an interactive onboarding wizard to conf ~ [ADR]
- Add cumulative savings section to session-end hook
- Introduce repository-aware YAML configuration, con ~ [ADR]
- Ensure Claude OAuth usage is always refreshed and ~ [ADR]
- Introduce MCP-aware routing and enforce-route bloc ⚠ [ADR]

**Most changed files:**
- `.claude-plugin/marketplace.json`
- `.claude-plugin/plugin.json`
- `.factory-plugin/marketplace.json`
- `.factory-plugin/plugin.json`
- `CHANGELOG.md`

---
